@@ -5,9 +5,10 @@ from thunderpush.sortingstation import SortingStation
 logger = logging.getLogger()
 
 try:
-    import json
+    import simplejson as json
 except ImportError:
-    import simplejson as json 
+    import json # NOQA
+
 
 def is_authenticated(f):
     """ Decorator used to check if a valid api key has been provided. """
@@ -18,7 +19,7 @@ def is_authenticated(f):
         apisecret = self.request.headers.get('X-Thunder-Secret-Key', None)
         messenger = ss.get_messenger_by_apikey(kwargs['apikey'])
 
-        if not messenger or apisecret != messenger.apisecret:  
+        if not messenger or apisecret != messenger.apisecret:
             self.error("Wrong API key/secret.", 401)
             return
 
@@ -29,6 +30,7 @@ def is_authenticated(f):
 
     return run_check
 
+
 def is_json(f):
     """ Used to check if the body of the request is valid JSON. """
 
@@ -42,10 +44,11 @@ def is_json(f):
 
     return run_check
 
+
 class ThunderApiHandler(tornado.web.RequestHandler):
     def response(self, data, code=200):
         if code != 200:
-            # if something went wrong, we include returned HTTP code in the 
+            # if something went wrong, we include returned HTTP code in the
             # JSON response
             data["status"] = code
 
@@ -55,6 +58,7 @@ class ThunderApiHandler(tornado.web.RequestHandler):
     def error(self, message, code=500):
         self.response({"message": message}, code)
 
+
 class ChannelHandler(ThunderApiHandler):
     @is_authenticated
     @is_json
@@ -75,11 +79,13 @@ class ChannelHandler(ThunderApiHandler):
 
         messenger = kwargs['messenger']
         channel = kwargs['channel']
-        
-        users = [user.userid for user in messenger.get_users_in_channel(channel)]
+
+        users = \
+            [user.userid for user in messenger.get_users_in_channel(channel)]
 
         self.response({"users": users})
 
+
 class UserCountHandler(ThunderApiHandler):
     """ Retrieves the number of users online. """
 
@@ -89,6 +95,7 @@ class UserCountHandler(ThunderApiHandler):
 
         self.response({"count": messenger.get_user_count()})
 
+
 class UserHandler(ThunderApiHandler):
     @is_authenticated
     def get(self, *args, **kwargs):
@@ -96,7 +103,7 @@ class UserHandler(ThunderApiHandler):
 
         messenger = kwargs['messenger']
         user = kwargs['user']
-        
+
         is_online = messenger.is_user_online(user)
         self.response({"online": is_online}, 200)
 
@@ -112,3 +119,15 @@ class UserHandler(ThunderApiHandler):
         self.response({"count": count})
 
         logger.debug("Message has been sent to %d users." % count)
+
+    @is_authenticated
+    def delete(self, *args, **kwargs):
+        """ Forces logout of a user. """
+
+        messenger = kwargs['messenger']
+        user = kwargs['user']
+
+        messenger.force_disconnect_user(user)
+
+        # no response
+        self.set_status(204)
