@@ -1,16 +1,16 @@
 import logging
 
 from sockjs.tornado import SockJSConnection
-from thunderpush.messenger import Messenger
 from thunderpush.sortingstation import SortingStation
 
 try:
-    import json
+    import simplejson as json
 except ImportError:
-    import simplejson as json 
+    import json # NOQA
 
 logger = logging.getLogger()
 
+
 class ThunderSocketHandler(SockJSConnection):
     def on_open(self, info):
         logger.debug("New connection opened.")
@@ -28,9 +28,12 @@ class ThunderSocketHandler(SockJSConnection):
             self.messenger.unregister_user(self)
             self.messenger = None
 
-        logger.debug("User %s has disconnected." 
+        logger.debug("User %s has disconnected."
             % getattr(self, "userid", None))
 
+    def force_disconnect(self):
+        self.close(9002, "Server closed the connection (intentionally).")
+
     def process_message(self, msg):
         """
         We assume that every client message comes in following format:
@@ -69,15 +72,14 @@ class ThunderSocketHandler(SockJSConnection):
         if self.messenger:
             self.messenger.register_user(self)
         else:
-            logger.warning("Invalid API key.")
-
-            # inform client that the key was not good
-            self.send("WRONGKEY")
-            self.close()
+            self.close(9000, "Invalid API key.")
 
     def handle_subscribe(self, args):
         if not self.connected:
             logger.warning("User not connected.")
+
+            # close the connection, the user issues commands in a wrong order
+            self.close(9001, "Subscribing before connecting.")
             return
 
         channels = args.split(":")
@@ -86,7 +88,9 @@ class ThunderSocketHandler(SockJSConnection):
             for channel in channels:
                 self.messenger.subsribe_user_to_channel(self, channel)
 
+    def close(self, code=3000, message="Go away!"):
+        self.session.close(code, message)
+
     @property
     def connected(self):
         return bool(self.messenger)
-    
\ No newline at end of file
