@@ -3,12 +3,13 @@ import re
 
 logger = logging.getLogger()
 
+
 class Messenger(object):
-    """ 
+    """
     Handles dispatching messages to Channels and Users
     for given client.
     """
-    
+
     def __init__(self, apikey, apisecret, *args, **kwargs):
         self.apikey = apikey
         self.apisecret = apisecret
@@ -18,10 +19,10 @@ class Messenger(object):
 
     @staticmethod
     def is_valid_channel_name(name):
-        return re.match("^[a-zA-Z0-9_\-\=\@\,\.\;]{1,64}$", name) != None
+        return not re.match("^[a-zA-Z0-9_\-\=\@\,\.\;]{1,64}$", name) is None
 
     def send_to_channel(self, channel, message):
-        """ 
+        """
         Sends a message to given channel.
         Returns a count of messages sent.
         """
@@ -30,7 +31,7 @@ class Messenger(object):
         return self._send_to_users(users, message)
 
     def send_to_user(self, userid, message):
-        """ 
+        """
         Sends a message to given user.
         Returns a count of messages sent.
         """
@@ -39,8 +40,8 @@ class Messenger(object):
         return self._send_to_users(users, message)
 
     def _send_to_users(self, users, message):
-        for user in users:
-            user.send(message)
+        if users:
+            users[0].broadcast(users, message)
 
         return len(users)
 
@@ -53,21 +54,43 @@ class Messenger(object):
             self.channels.setdefault(channel, []).append(user)
 
             logger.debug("%s subscribed to %s." % (user.userid, channel,))
-            logger.debug("User count in %s: %d." % 
+            logger.debug("User count in %s: %d." %
                 (channel, self.get_channel_user_count(channel)))
         else:
             logger.debug("Invalid channel name %s." % channel)
 
     def unregister_user(self, user):
+        channels_to_free = []
+
         for name in self.channels.iterkeys():
             try:
                 self.channels[name].remove(user)
+
+                # as we can't delete keys from the dict as we are iterating
+                # over it, we do it outside of this loop
+                if len(self.channels[name]) == 0:
+                    channels_to_free.append(name)
             except ValueError:
                 pass
 
-        self.user_count -= 1
+        # free up the memory used by empty channel index
+        for channel in channels_to_free:
+            del self.channels[channel]
+
         self.users[user.userid].remove(user)
 
+        # free up the memory used by empty user index
+        if len(self.users[user.userid]) == 0:
+            del self.users[user.userid]
+
+        self.user_count -= 1
+
+    def force_disconnect_user(self, userid):
+        handlers = self.users.get(userid, [])
+
+        for handler in handlers:
+            handler.force_disconnect()
+
     def get_user_count(self):
         return self.user_count
 
